@@ -61,7 +61,8 @@
 #' }
 #' 
 #' Further columns will be included depending on the requested output format (expanded = TRUE or FALSE).
-#' 
+#' Columns that end in "_reported" are the originally reported timezones, 
+#' but the "tz_cd" column defines the timezone of any POSIXct columns.
 #' 
 #' There are also several useful attributes attached to the data frame:
 #' \tabular{lll}{
@@ -135,7 +136,7 @@ readNWISqw <- function (siteNumbers,parameterCd,startDate="",endDate="",
   url <- attr(data, "url")
   comment <- attr(data, "comment")
   queryTime <- attr(data, "queryTime")
-  header <- attr(data, "header")
+  header <- attr(data, "headerInfo")
   
   if(reshape){
     if(expanded){
