@@ -60,7 +60,7 @@
 #' }
 #' @export
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' siteINFO <- readNWISsite('05114000')
 #' siteINFOMulti <- readNWISsite(c('05114000','09423350'))
 #' }
@@ -73,6 +73,8 @@ readNWISsite <- function(siteNumbers){
    
   data <- importRDB1(urlSitefile,asDateTime=FALSE)
   #readr needs multiple lines to convert to anything but characters:  
+  data[grep("_va",names(data))][data[grep("_va",names(data))] == "."] <- NA
+  
   data[,grep("_va",names(data))] <- sapply(data[,grep("_va",names(data))], as.numeric)
 
   return(data)
